#!/usr/local/bin/python3.8
# -*- coding: utf-8 -*-

"""
udvd2srt : converts MicroDVD subtitles into SubRip format

USAGE
  udvd2srt udvdfile > srt
"""

import sys		# sys args
import re		# regular expressions



def convert( line, fps, line_count ):

	# input/MicroDVD format is : "{start}{end}text"
	match = re.match(u"{(\d+)}{(\d+)}(.*)",line)
	start = int(match.groups()[0])
	end = int(match.groups()[1])
	text = match.groups()[2]

	# output/SubRip format is :
	#
	# 1
	# 00:02:36,623 --> 00:02:38,523
	# The same hand has struck again.
	#
	# 2
	# 00:02:38,625 --> 00:02:42,721
	# This time the victim is a nurse.
	#
	# ...

	line_count = line_count + 1
	times = dict()

	for (n,time) in [(0,start),(1,end)]:
		ms = time % fps
		ss = time / fps
		time = time / fps
		mn = time % 60
		time = time / 60
		hh = time
		times[n] = { 'hh': hh, 'mn': mn, 'ss': ss, 'ms': ms }

	return line_count, """%d
	%2.2d:%2.2d:%2.2d,%3.3d --> %2.2d:%2.2d:%2.2d,%3.3d
	%s
	""" % ( line_count,
		times[0]['hh'], times[0]['mn'], times[0]['ss'], times[0]['ms'],
		times[1]['hh'], times[1]['mn'], times[1]['ss'], times[1]['ms'],
		text )



def main(argv=None):

	if argv is None:
		argv = sys.argv

	if len(argv) < 2:
		sys.exit(__doc__+"\nNot enough arguments")

	line_count = 0

	try:
		fps = int(argv[1])
	except:
		sys.exit(__doc__+"\nNeed an integer")

	# A. reads from the standard input
	fin = None
	if argv[2] == "--":
		line = sys.stdin.readline()
		while len(line) > 0:
			line_count, text = convert(line,fps,line_count)
			print text
			line = sys.stdin.readline()
	# B. reads from a file
	else:
		fin = open(argv[2])
		for line in fin:
			line_count, text = convert(line,fps,line_count)
			print text



if __name__ == "__main__":

	sys.exit(main())


